.. _quickstart:

==========
Quickstart
==========

Downloading and installing
==========================

.. toctree::
   :maxdepth: 1

   users/install
   users/vagrant

Beginner's guide
================

Beginner's tutorials (IPython Notebooks). `Available here`__

Michael Notter's Nipype guide. `Available here`__

Dissecting Nipype Workflows. `Available here`__

Introductory slides [older]. `Available here`__

__ https://github.com/mwaskom/nipype_concepts
__ http://miykael.github.com/nipype-beginner-s-guide/index.html
__ http://slideviewer.herokuapp.com/url/raw.github.com/nipy/nipype/master/examples/nipype_tutorial.ipynb?theme=sky
__ http://satra.github.com/intro2nipype

User guides
===========

.. toctree::
   :maxdepth: 1

   users/interface_tutorial
   users/pipeline_tutorial
   users/plugins
   users/debug

Developer guides
================

.. toctree::
   :maxdepth: 1

   devel/writing_custom_interfaces
   devel/gitwash/index

.. include:: links_names.txt

Useful links for beginners
===========================

Getting started with Python - Tutorials. `Available here`__

Python for Beginners `Available here`__

   __ http://www.codecademy.com/en/tracks/python
   __ https://www.python.org/about/gettingstarted/
